# image-dataset-converter-pdf
PDF support for the image-dataset-converter library.


## Installation

Via PyPI:

```bash
pip install image-dataset-converter-pdf
```

The latest code straight from the repository:

```bash
pip install git+https://github.com/waikato-datamining/image-dataset-converter-pdf.git
```


## Plugins

See [here](plugins/README.md) for an overview of all plugins.

